using System;
using System.Collections.Generic;
using NUnit.Framework;
using Rhino.Mocks;
using Rhino.Mocks.Impl;
using Rhino.Mocks.Interfaces;
using RhinoMockDemo;
using RhinoMockDemo.DBOs;
using RhinoMockDemo.Providers;

namespace TestLib
{
	[TestFixture]
	public class CustomerPresenterTests_backup
	{
		private MockRepository _mock;
		private CustomerPresenter _presenter;
		private ICustomerView _view;
		private IClassFactory _factory;
		private ICustomerDbo _dbo;

		[SetUp]
		public void Setup()
		{
			_mock = new MockRepository();
			_view = _mock.CreateMock<ICustomerView>();
			_factory = _mock.CreateMock<IClassFactory>();
			_dbo = _mock.CreateMock<ICustomerDbo>();
			_presenter = new CustomerPresenter(_view, _factory, _dbo);
		}

		[TearDown]
		public void TearDown()
		{
			_mock.VerifyAll();
		}

		[Test]
		public void Test_FullName()
		{
			//
			// set mocking expectations 
			//
			Expect.Call(_factory.CustomerDbo).Return(_dbo).Repeat.Any();
			ICustomer c = _mock.CreateMock<ICustomer>();
			Expect.Call(c.FirstName).Return("Chris");
			Expect.Call(c.LastName).Return("Brandsma");
			Expect.Call(c.Title).Return("Mr.");
			ICustomer c2 = _mock.CreateMock<ICustomer>();
			Expect.Call(c2.FirstName).Return("Chris");
			Expect.Call(c2.LastName).Return("Brandsma");
			Expect.Call(c2.Title).Return("");
			
			// set the expectations
			_mock.ReplayAll();
			//
			// run tests
			//
			//_presenter = new CustomerPresenter(_view, _factory);
			Assert.AreEqual("Mr. Chris Brandsma", _presenter.FullName(c));
			Assert.AreEqual("Chris Brandsma", _presenter.FullName(c2));
		}

		[Test]
		public void Test_DeleteCustomer()
		{
			_dbo.DeleteCustomer(1);
			// set the expectations
			_mock.ReplayAll();
			//
			// run tests
			//
			_presenter.DeleteCustomer(1);
		}
		
		[Test]
		public void Test_Initialize()
		{
			List<ICustomer> oList = new List<ICustomer>();
			oList.Add(new Customer(1, "xx1", "xx2", "xx3", "xx4"));
			Expect.Call(_dbo.GetAllCustomers()).Return(oList);
			_view.Customers = oList;
			_mock.ReplayAll();
			_presenter.Initialize();
		}
		
		[Test]
		public void Test_HandlesEvent()
		{
			_dbo.MyEvent += null;
			LastCall.IgnoreArguments();
			
			_mock.ReplayAll();
			_presenter.HandlesEvent();
		}

		private IEventRaiser _eventRaiser;

		[Test]
		public void Test_FiredEvent()
		{
			List<ICustomer> oList = new List<ICustomer>();
			oList.Add(new Customer(1, "xx1", "xx2", "xx3", "xx4"));
			Expect.Call(_dbo.GetAllCustomers()).Return(oList);
			_view.Customers = oList;

			_dbo.MyEvent += null;
			LastCall.Constraints(Is.NotNull());
			_eventRaiser = LastCall.GetEventRaiser();
			
			_mock.ReplayAll();
			_presenter.HandlesEvent();
			_eventRaiser.Raise(null, null);
					
		}
	}
}